@@ -1,5 +1,5 @@
 package CryptoTron::Modules;
-use Filter::Macro;  # <-- The magic is found here.
+use CryptoTron::MyFilterMacro;  # <-- The magic is found here.
 # Lines below will be expanded into caller's code.
 use CryptoTron::GetAccount;
 use CryptoTron::GetAccountNet;
@@ -8,4 +8,4 @@ use CryptoTron::GetReward;
 use CryptoTron::BroadcastTransaction;
 use CryptoTron::WithdrawBalance;
 use CryptoTron::ParseAccount;
-1;
+#1;
